package com.fastbee.iot.service.impl;

import java.util.List;
import com.fastbee.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fastbee.iot.mapper.ModbusParamsMapper;
import com.fastbee.iot.domain.ModbusParams;
import com.fastbee.iot.service.IModbusParamsService;

/**
 * 产品modbus配置参数Service业务层处理
 * 
 * @author kerwincui
 * @date 2024-05-31
 */
@Service
public class ModbusParamsServiceImpl implements IModbusParamsService 
{
    @Autowired
    private ModbusParamsMapper modbusParamsMapper;

    /**
     * 查询产品modbus配置参数
     * 
     * @param id 产品modbus配置参数主键
     * @return 产品modbus配置参数
     */
    @Override
    public ModbusParams selectModbusParamsById(Long id)
    {
        return modbusParamsMapper.selectModbusParamsById(id);
    }

    /**
     * 查询产品modbus配置参数列表
     * 
     * @param modbusParams 产品modbus配置参数
     * @return 产品modbus配置参数
     */
    @Override
    public List<ModbusParams> selectModbusParamsList(ModbusParams modbusParams)
    {
        return modbusParamsMapper.selectModbusParamsList(modbusParams);
    }

    /**
     * 新增产品modbus配置参数
     * 
     * @param modbusParams 产品modbus配置参数
     * @return 结果
     */
    @Override
    public int insertModbusParams(ModbusParams modbusParams)
    {
        modbusParams.setCreateTime(DateUtils.getNowDate());
        return modbusParamsMapper.insertModbusParams(modbusParams);
    }

    /**
     * 修改产品modbus配置参数
     * 
     * @param modbusParams 产品modbus配置参数
     * @return 结果
     */
    @Override
    public int updateModbusParams(ModbusParams modbusParams)
    {
        modbusParams.setUpdateTime(DateUtils.getNowDate());
        return modbusParamsMapper.updateModbusParams(modbusParams);
    }

    /**
     * 批量删除产品modbus配置参数
     * 
     * @param ids 需要删除的产品modbus配置参数主键
     * @return 结果
     */
    @Override
    public int deleteModbusParamsByIds(Long[] ids)
    {
        return modbusParamsMapper.deleteModbusParamsByIds(ids);
    }

    /**
     * 删除产品modbus配置参数信息
     * 
     * @param id 产品modbus配置参数主键
     * @return 结果
     */
    @Override
    public int deleteModbusParamsById(Long id)
    {
        return modbusParamsMapper.deleteModbusParamsById(id);
    }

    /**
     * 根据产品io获取modbus配置
     * @param productId
     * @return
     */
    @Override
    public ModbusParams getModbusParamsByProductId(Long productId){
        return modbusParamsMapper.getModbusParamsByProductId(productId);
    }

    /**
     * 根据设备id获取modbus配置
     * @param deviceId
     * @return
     */
    @Override
    public ModbusParams getModbusParamsByDeviceId(Long deviceId){
        return modbusParamsMapper.getModbusParamsByDeviceId(deviceId);
    }
}
